@@ -8,6 +8,7 @@ import pickle
 import shutil
 from collections import OrderedDict
 
+import numpy as np
 import pandas as pd
 
 from hypernets.utils.common import isnotebook, to_repr
@@ -78,16 +79,33 @@ class Trial():
         except AttributeError:
             state = self.__dict__
 
-        state = {k: v for k, v in state.items() if k != 'memo'}
+        # state = {k: v for k, v in state.items() if k != 'memo'}
+        memo = state.get('memo', None)
+        big_data_types = (pd.Series, pd.DataFrame, np.ndarray)
+        big_data_exists = isinstance(memo, dict) and any(isinstance(v, big_data_types) for v in memo.values())
+        if big_data_exists:
+            compacted_memo = {k: v for k, v in memo.items() if not isinstance(v, big_data_types)}
+            state = state.copy()
+            state['memo'] = compacted_memo
+
         return state
 
     def to_df(self, include_params=False):
         out = OrderedDict(trial_no=self.trial_no, succeeded=self.succeeded, reward=self.reward, elapsed=self.elapsed)
+        if isinstance(self.memo, dict):
+            out.update(self.memo)
+
         if include_params:
             for p in self.space_sample.get_assigned_params():
                 out[p.alias] = p.value
         return pd.DataFrame({k: [v] for k, v in out.items()})
 
+    def get_model(self):
+        from hypernets.utils import fs
+        with fs.open(self.model_file, 'rb') as f:
+            obj = pickle.load(f)
+        return obj
+
 
 class TrialHistory():
     def __init__(self, optimize_direction):
