@@ -1,31 +1,22 @@
 # -*- encoding: utf-8 -*-
+import json
+import tempfile
 import os
+from collections import OrderedDict
 from pathlib import Path
 from typing import Dict, Optional
 
 import psutil
 
+from hypernets.hyperctl import consts
 from hypernets.utils import logging
-
+from hypernets.utils.common import generate_short_id
 
 logger = logging.getLogger(__name__)
 
 
-class ExecutionConf:
-    def __init__(self, command, data_dir, working_dir):
-        self.command = command
-        self.data_dir = data_dir
-        self.working_dir = working_dir
+class _ShellJob:  # internal class
 
-    def to_config(self):
-        return {
-            "command": self.command,
-            "data_dir": self.data_dir,
-            "working_dir": self.working_dir
-        }
-
-
-class ShellJob:
     STATUS_INIT = 'init'
     STATUS_RUNNING = 'running'
     STATUS_SUCCEED = 'succeed'
@@ -33,23 +24,43 @@ class ShellJob:
 
     FINAL_STATUS = [STATUS_SUCCEED, STATUS_FAILED]
 
-    def __init__(self, name, params, command, output_dir, working_dir=None, assets=None, resource=None):
+    def __init__(self,  *, name, batch, params, working_dir=None, assets=None, resource=None):
+
         self.name = name
+        self.batch = batch
         self.params = params
         self.resource = resource
-        self.command = command
-        self.output_dir = output_dir
+
+        # write job files to tmp
+        self.data_dir_path = Path(tempfile.gettempdir()) \
+                             / f"{consts.JOB_DATA_DIR_PREFIX}{self.batch.name}_{self.name}_{generate_short_id()}"
 
         if working_dir is None:
-            self.working_dir = output_dir
+            self.working_dir = self.data_dir_path.as_posix()
         else:
             self.working_dir = working_dir
 
         self.assets = [] if assets is None else assets
 
-        self.start_time = None
-        self.end_time = None
-        self._status = ShellJob.STATUS_INIT
+        self.start_datetime = None
+        self.end_datetime = None
+
+        self._status = _ShellJob.STATUS_INIT
+        self._ext = {}
+
+    @property
+    def ext(self):
+        return self._ext
+
+    def set_ext(self, ext):
+        self._ext = ext
+
+    def state_data_file(self):  # on master node
+        return (self.batch.data_dir_path / f"{self.name}.json").as_posix()
+
+    def state_data(self):
+        with open(self.state_data_file(), 'r') as f:
+            return json.load(f)
 
     def set_status(self, status):
         self._status = status
@@ -59,21 +70,16 @@ class ShellJob:
         return self._status
 
     @property
-    def job_data_dir(self):
-        return Path(self.output_dir).as_posix()
-
-    @property
-    def run_file_path(self):
-        return (Path(self.job_data_dir) / "run.sh").as_posix()
+    def run_file(self):
+        return (self.data_dir_path / "run.sh").as_posix()
 
     @property
     def resources_path(self):
-        return Path(self.job_data_dir) / "resources"  # resources should be copied to working dir
+        return self.data_dir_path / "resources"  # resources should be copied to working dir
 
     def to_dict(self):
         import copy
         config_dict = copy.copy(self.to_config())
-        config_dict['status'] = self.status
         return config_dict
 
     def to_config(self):
@@ -81,16 +87,14 @@ class ShellJob:
             "name": self.name,
             "params": self.params,
             "resource": self.resource,
-            "command": self.command,
-            "output_dir": self.output_dir,
             "working_dir": self.working_dir,
             "assets": self.assets
         }
 
     @property
     def elapsed(self):
-        if self.start_time is not None and self.end_time is not None:
-            return self.end_time - self.start_time
+        if self.start_datetime is not None and self.end_datetime is not None:
+            return self.end_datetime - self.start_datetime
         else:
             return None
 
@@ -136,25 +140,36 @@ class Batch:
     STATUS_RUNNING = "RUNNING"
     STATUS_FINISHED = "FINISHED"
 
-    def __init__(self, name, working_dir: str):
+    def __init__(self, *, name, job_command, data_dir: str):
         self.name = name
-        self.working_dir_path = Path(working_dir)
-
-        self.jobs = []
+        self.job_command = job_command
+        self.data_dir = data_dir
 
+        self._jobs_dict = OrderedDict()
         self.start_time = None
         self.end_time = None
 
+    @property
+    def data_dir_path(self):
+        return Path(self.data_dir)
+
+    @property
+    def jobs(self):
+        return list(self._jobs_dict.values())
+
     def job_status_file_path(self, job_name, status):
-        return (self.working_dir_path / f"{job_name}.{status}").as_posix()
+        return (self.data_dir_path / f"{job_name}.{status}").as_posix()
+
+    def job_state_data_file_path(self, job_name):
+        return (self.data_dir_path / f"{job_name}.json").as_posix()
 
     def status_files(self):
-        return self._status_files([ShellJob.STATUS_FAILED, ShellJob.STATUS_SUCCEED, ShellJob.STATUS_RUNNING])
+        return self._status_files([_ShellJob.STATUS_FAILED, _ShellJob.STATUS_SUCCEED, _ShellJob.STATUS_RUNNING])
 
     def _status_files(self, statuses):
         return {status: f"{self.name}.{status}" for status in statuses}
 
-    def load_job_status(self, job_name):
+    def get_persisted_job_status(self, job_name):
         exists_statuses = []
         for status_value, status_file in self.status_files().items():
             abs_status_file = self.job_status_file_path(job_name, status_value)
@@ -168,15 +183,11 @@ class Batch:
         elif status_len == 1:
             return exists_statuses[0][0]
         else:  # no status file
-            return ShellJob.STATUS_INIT
+            return _ShellJob.STATUS_INIT
 
-    def add_job(self, **kwargs):
-        if kwargs.get('resource') is None:
-            kwargs['resource'] = {
-                'cpu': -1,
-                'mem': -1
-            }
-        self.jobs.append(ShellJob(**kwargs))
+    def add_job(self, name, **kwargs):
+        assert name not in self._jobs_dict, f'job {name} is already exists'  # check job name
+        self._jobs_dict[name] = _ShellJob(name=name, batch=self, **kwargs)
 
     def status(self):
         pid = self.pid()
@@ -193,13 +204,13 @@ class Batch:
 
     def is_finished(self):
         exists_status = set([job.status for job in self.jobs])
-        return exists_status.issubset(set(ShellJob.FINAL_STATUS))
+        return exists_status.issubset(set(_ShellJob.FINAL_STATUS))
 
     def config_file_path(self):
-        return self.working_dir_path / self.FILE_CONFIG
+        return self.data_dir_path / self.FILE_CONFIG
 
     def pid_file_path(self):
-        return self.working_dir_path / self.FILE_PID
+        return self.data_dir_path / self.FILE_PID
 
     def pid(self):
         pid_file_path = self.pid_file_path()
@@ -209,19 +220,12 @@ class Batch:
         else:
             return None
 
-    def get_job_by_name(self, job_name) -> Optional[ShellJob]:
+    def get_job_by_name(self, job_name) -> Optional[_ShellJob]:
         for job in self.jobs:
             if job.name == job_name:
                 return job
         return None
 
-    @property
-    def elapsed(self):
-        if self.start_time is not None and self.end_time is not None:
-            return self.end_time - self.start_time
-        else:
-            return None
-
     def summary(self):
         batch = self
 
@@ -235,9 +239,15 @@ class Batch:
             "name": batch.name,
             'status': batch.status(),
             'total': len(batch.jobs),
-            ShellJob.STATUS_FAILED: cnt(ShellJob.STATUS_FAILED),
-            ShellJob.STATUS_INIT: cnt(ShellJob.STATUS_INIT),
-            ShellJob.STATUS_SUCCEED: cnt(ShellJob.STATUS_SUCCEED),
-            ShellJob.STATUS_RUNNING: cnt(ShellJob.STATUS_RUNNING),
+            _ShellJob.STATUS_FAILED: cnt(_ShellJob.STATUS_FAILED),
+            _ShellJob.STATUS_INIT: cnt(_ShellJob.STATUS_INIT),
+            _ShellJob.STATUS_SUCCEED: cnt(_ShellJob.STATUS_SUCCEED),
+            _ShellJob.STATUS_RUNNING: cnt(_ShellJob.STATUS_RUNNING),
         }
 
+    @property
+    def elapsed(self):
+        if self.start_time is not None and self.end_time is not None:
+            return self.end_time - self.start_time
+        else:
+            return None
